CREATE TABLE ADR (
  ID SERIAL,
  ID_ID INTEGER,
  FOTO_ID INTEGER,
  BEZEICHNUNG VARCHAR(100) NOT NULL,
  FIRMA VARCHAR(50),
  STRASSE VARCHAR(50),
  PLZ VARCHAR(15),
  ORT VARCHAR(50),
  LAND VARCHAR(50),
  NAME VARCHAR(50),
  TELEFON VARCHAR(50),
  TELEFON2 VARCHAR(50),
  MOBIL VARCHAR(50),
  FAX VARCHAR(50),
  EMAIL VARCHAR(50),
  EMAIL2 VARCHAR(50),
  INTERNET VARCHAR(250),
  KUNDNR VARCHAR(30),
  LOGIN VARCHAR(50),
  PASSWORT VARCHAR(50),
  USSTID VARCHAR(25),
  GEBDATUM DATE,
  BANK VARCHAR(40),
  BLZ VARCHAR(40),
  KONTO VARCHAR(40),
  SWIFT VARCHAR(40),
  IBAN VARCHAR(40),
  LIEFERANT INTEGER,
  HERSTELLER INTEGER,
  PROJEKT INTEGER,
  PRIVAT INTEGER,
  GESPERRT INTEGER,
  OPTZ INTEGER,
  OPTQ INTEGER,
  RABATT DOUBLE PRECISION,
  BEWERTUNG INTEGER,
  BEWDATUM DATE,
  UPDATEDATUM DATE,
  HANDBUCH VARCHAR(250),
  INFO VARCHAR(255),
  BEMERKUNG TEXT,
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT ADR_ID_PX PRIMARY KEY (ID),
  CONSTRAINT ADR_BEZEICHNUNG_IX UNIQUE (BEZEICHNUNG)
);

CREATE TABLE BAUTEIL (
  ID SERIAL,
  TREE_TYP_ID INTEGER NOT NULL,
  FOTO_ID INTEGER,
  BEZEICHNUNG VARCHAR(100) NOT NULL,
  BESCHREIBUNG TEXT,
  HANDBUCH VARCHAR(250),
  LIBRARY VARCHAR(70),
  KENNZ INTEGER,
  INFO VARCHAR(255),
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT BAUTEIL_ID_PX PRIMARY KEY (ID),
  CONSTRAINT BAUTEIL_BEZEICHNUNG_IX UNIQUE (BEZEICHNUNG)
);

CREATE TABLE BAUTEILADR (
  ID SERIAL,
  BAUTEIL_ID INTEGER NOT NULL,
  ADR_ID INTEGER NOT NULL,
  BAUTEILLAGER_ID INTEGER,
  FOTO_ID INTEGER,
  BESTELLNR VARCHAR(50),
  EPREIS DOUBLE PRECISION,
  RABATT DOUBLE PRECISION,
  EPMENGE INTEGER,
  VPEMENGE INTEGER,
  DIVMENGE INTEGER,
  BEMERKUNG TEXT,
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT BAUTEILADR_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE BAUTEILLAGER (
  ID SERIAL,
  BAUTEIL_ID INTEGER NOT NULL,
  GEHAUSE_ID INTEGER,
  KISTE_ID INTEGER,
  ADR_ID INTEGER,
  FOTO_ID INTEGER,
  BEZEICHNUNG VARCHAR(100),
  ARTIKELNR VARCHAR(40),
  ARTIKELNR2 VARCHAR(40),
  SMD INTEGER NOT NULL DEFAULT '0',
  SMD_TEXT VARCHAR(50),
  MENGE INTEGER,
  MENGEV INTEGER,
  MENGEMIN INTEGER,
  EPREIS DOUBLE PRECISION,
  VPREIS DOUBLE PRECISION,
  HALTBAR DATE,
  LAGERNR VARCHAR(40),
  ART INTEGER,
  BWARE INTEGER,
  ROHS INTEGER,
  BEMERKUNG TEXT,
  HANDBUCH VARCHAR(250),
  LIBRARY VARCHAR(70),
  KENNZ INTEGER,
  STORE INTEGER,
  STOREMENGE DOUBLE PRECISION,
  INFO VARCHAR(255),
  GEWICHT DOUBLE PRECISION,
  BARCODE VARCHAR(30),
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT BAUTEILLAGER_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE BAUTEILBEWEGUNG (
  ID SERIAL,
  BAUTEIL_ID INTEGER NOT NULL,
  BAUTEILLAGER_ID INTEGER NOT NULL,
  BESTELLEN_ID INTEGER,
  PROJEKT_ID INTEGER,
  PROJEKTPOS_ID INTEGER,
  USERNAME VARCHAR(50),
  COMPUTERNAME VARCHAR(50),
  GRUND VARCHAR(200),
  PMMENGE INTEGER,
  MENGE INTEGER,
  DATUM TIMESTAMP,
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT BAUTEILBEWEGUNG_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE BESTELLEN (
  ID SERIAL,
  BAUTEIL_ID INTEGER,
  BAUTEILLAGER_ID INTEGER,
  FOTO_ID INTEGER,
  PROJEKT_ID INTEGER,
  BEZEICHNUNG VARCHAR(100),
  AUFTRAG VARCHAR(100),
  MENGE INTEGER,
  STATUS INTEGER,
  SDATUM DATE,
  TERMIN1 DATE,
  TERMIN2 DATE,
  ARCHIV INTEGER,
  BEMERKUNG TEXT,
  HANDBUCH VARCHAR(250),
  INFO VARCHAR(255),
  USELIEF12 INTEGER,
  LIEF_MENGEVPE INTEGER,
  LIEF_MENGEVPESUM INTEGER,
  LAGER_MENGEVPESUM INTEGER,
  LIEF1_ADR_ID INTEGER,
  LIEF1_BAUTEILADR_ID INTEGER,
  LIEF1_BESTELLNR VARCHAR(50),
  LIEF1_MENGEVPE INTEGER,
  LIEF1_EPREIS DOUBLE PRECISION,
  LIEF1_RABATT DOUBLE PRECISION,
  LIEF1_GPREIS DOUBLE PRECISION,
  LIEF2_ADR_ID INTEGER,
  LIEF2_BAUTEILADR_ID INTEGER,
  LIEF2_BESTELLNR VARCHAR(50),
  LIEF2_MENGEVPE INTEGER,
  LIEF2_EPREIS DOUBLE PRECISION,
  Lief2_RABATT DOUBLE PRECISION,
  LIEF2_GPREIS DOUBLE PRECISION,
  Kennz INTEGER,
  Prio INTEGER,
  OptA INTEGER,
  OptB INTEGER,
  OptC INTEGER,
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT BESTELLEN_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE FOTO (
  ID SERIAL,
  ID_ID INTEGER,
  BEZEICHNUNG VARCHAR(100),
  TABELLE VARCHAR(30),
  BILDTYP VARCHAR(10) NOT NULL,
  BILD BYTEA,
  BILDDATEI VARCHAR(255),
  POSX0 INTEGER,
  POSY0 INTEGER,
  POSXFAK DOUBLE PRECISION,
  POSYFAK DOUBLE PRECISION,
  POSTOP INTEGER,
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT FOTO_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE GEHAUSE (
  ID SERIAL,
  FOTO_ID INTEGER,
  BEZEICHNUNG VARCHAR(100) NOT NULL,
  TYP VARCHAR(50),
  NORMBEZ VARCHAR(50),
  HERSTELLERBEZ VARCHAR(50),
  LIBRARY VARCHAR(70),
  PINS INTEGER,
  RASTER DOUBLE PRECISION,
  GEWICHT DOUBLE PRECISION,
  BEMERKUNG TEXT,
  HANDBUCH VARCHAR(250),
  INFO VARCHAR(255),
  SMD INTEGER NOT NULL,
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT GEHAUSE_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE HISTORIE (
  ID SERIAL,
  PROJEKT_ID INTEGER,
  PROJEKTPOS_ID INTEGER,
  KOSTEN_ID INTEGER,
  FOTO_ID INTEGER,
  ADR_ID INTEGER,
  ADRK_ID INTEGER,
  DATUM DATE,
  PROJEKT VARCHAR(100),
  BEZEICHNUNG VARCHAR(100),
  BESCHREIBUNG TEXT,
  VERSION VARCHAR(30),
  STATUS INTEGER,
  FSTATUS INTEGER,
  SNR VARCHAR(40),
  GNR VARCHAR(40),
  FDATUM DATE,
  FVERSION VARCHAR(30),
  KENNZ INTEGER,
  AUFWAND DOUBLE PRECISION,
  Vorgehen INTEGER,
  ABRECHNUNG INTEGER,
  GPREIS DOUBLE PRECISION,
  HANDBUCH VARCHAR(250),
  INFO VARCHAR(255),
  KUNDEBES TEXT,
  REPNR VARCHAR(50),
  REPFEHLER VARCHAR(50),
  REPBES TEXT,
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT HISTORIE_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE KISTE (
  ID SERIAL,
  FOTO_ID INTEGER,
  BEZEICHNUNG VARCHAR(100) NOT NULL,
  NUMMER INTEGER,
  POSX INTEGER,
  POSY INTEGER,
  LAGERORT VARCHAR(100),
  GROESSE VARCHAR(100),
  BEMERKUNG TEXT,
  HANDBUCH VARCHAR(250),
  INFO VARCHAR(255),
  PARETIKETT VARCHAR(150),
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT KISTE_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE KOSTEN (
  ID SERIAL,
  PROJEKT_ID INTEGER,
  ADR_ID INTEGER,
  ADRK_ID INTEGER,
  FOTO_ID INTEGER,
  BEZEICHNUNG VARCHAR(100),
  BESCHREIBUNG TEXT,
  STATUS INTEGER,
  AUFTRAG VARCHAR(50),
  BESTELLNR VARCHAR(50),
  RABATT DOUBLE PRECISION,
  GPREIS DOUBLE PRECISION,
  DANGEBOT DATE,
  DGUELTIG DATE,
  DLIEF DATE,
  DABNAHME DATE,
  INFO VARCHAR(255),
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT KOSTEN_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE KOSTENPOS (
  ID SERIAL,
  PROJEKT_ID INTEGER,
  KOSTEN_ID INTEGER,
  PROJEKTPOS_ID INTEGER,
  BAUTEIL_ID INTEGER,
  BAUTEILLAGER_ID INTEGER,
  FOTO_ID INTEGER,
  NR INTEGER,
  BEZEICHNUNG VARCHAR(100),
  BESCHREIBUNG TEXT,
  STATUS INTEGER,
  MENGE DOUBLE PRECISION,
  VPREIS DOUBLE PRECISION,
  RABATT DOUBLE PRECISION,
  VPSUM DOUBLE PRECISION,
  ARTIKELNR VARCHAR(40),
  BARCODE VARCHAR(30),
  TERMIN DATE,
  DLIEF DATE,
  INFO VARCHAR(255),
  ART INTEGER,
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT KOSTENPOS_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE PARAM (
  ID SERIAL,
  PARNR INTEGER,
  PARNAME VARCHAR(40),
  LAND VARCHAR(5),
  VALINT INTEGER,
  VALFLOAT DOUBLE PRECISION,
  VALTEXT VARCHAR(250),
  VALMEMO TEXT,
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT PARAM_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE PROJEKT (
  ID SERIAL,
  ID_ID INTEGER,
  FOTO_ID INTEGER,
  BAUTEIL_ID INTEGER,
  BAUTEILLAGER_ID INTEGER,
  ADR_ID INTEGER,
  BEZEICHNUNG VARCHAR(100) NOT NULL,
  BESCHREIBUNG TEXT,
  KENNZ INTEGER,
  MENGEFERTIG INTEGER,
  MENGEOFFEN INTEGER,
  VPREIS DOUBLE PRECISION,
  TERMIN DATE,
  HANDBUCH VARCHAR(250),
  INFO VARCHAR(255),
  OPTA INTEGER,
  OPTB INTEGER,
  OPTC INTEGER,
  WARTUNG DATE,
  INTERVALL VARCHAR(40),
  AUFTRAG VARCHAR(50),
  SNR VARCHAR(40),
  VARIANTE VARCHAR(200),
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT PROJEKT_ID_PX PRIMARY KEY (ID),
  CONSTRAINT PROJEKT_BEZEICHNUNG_IX UNIQUE (BEZEICHNUNG)
);

CREATE TABLE PROJEKTPOS (
  ID SERIAL,
  PROJEKT_ID INTEGER NOT NULL,
  BAUTEIL_ID INTEGER,
  BAUTEILLAGER_ID INTEGER,
  FOTO_ID INTEGER,
  BEZEICHNUNG VARCHAR(100),
  ARTIKELNR VARCHAR(40),
  BEMERKUNG TEXT,
  SYMBOL VARCHAR(50),
  WERT VARCHAR(50),
  GEHAUSE VARCHAR(50),
  MENGE INTEGER,
  EPREIS DOUBLE PRECISION,
  RABATT DOUBLE PRECISION,
  GPREIS DOUBLE PRECISION,
  ART INTEGER,
  KENNZ INTEGER,
  VARIANTE VARCHAR(50),
  POSX INTEGER,
  POSY INTEGER,
  POSZ INTEGER,
  POSR INTEGER,
  TOP INTEGER,
  SMD INTEGER,
  STATUS INTEGER,
  BARCODE VARCHAR(30),
  SNR VARCHAR(40),
  HANDBUCH VARCHAR(250),
  INFO VARCHAR(255),
  DRUCK INTEGER,
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT PROJEKTPOS_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE TRANSLATE (
  ID SERIAL,
  SWTYP INTEGER,
  BEZNAME VARCHAR(100) NOT NULL,
  CURRENT VARCHAR(250),
  DE VARCHAR(250),
  DE_WAREN VARCHAR(250),
  EN VARCHAR(250),
  ES VARCHAR(250),
  FR VARCHAR(250),
  IT VARCHAR(250),
  NL VARCHAR(250),
  PL VARCHAR(250),
  RU VARCHAR(250),
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT TRANSLATE_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE TREE_TYP (
  ID SERIAL,
  ID_ID INTEGER NOT NULL,
  FOTO_ID INTEGER,
  BEZEICHNUNG VARCHAR(100) NOT NULL,
  BARFORMAT VARCHAR(40) NULL,
  BEMERKUNG TEXT,
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT TREE_TYP_ID_PX PRIMARY KEY (ID)
);

CREATE TABLE WISSEN (
  ID SERIAL,
  FOTO_ID INTEGER,
  BEZEICHNUNG VARCHAR(100) NOT NULL,
  BESCHREIBUNG TEXT,
  BEMERKUNG TEXT,
  THEMA VARCHAR(50),
  STATUS INTEGER,
  OPTA INTEGER,
  OPTB INTEGER,
  OPTC INTEGER,
  INFO VARCHAR(255),
  KENNZ INTEGER,
  HANDBUCH VARCHAR(250),
  AENDDATUM TIMESTAMP NOT NULL DEFAULT 'NOW',
  CONSTRAINT WISSEN_ID_PX PRIMARY KEY (ID)
);

CREATE FUNCTION "IF"(IN b boolean, IN "fTrue" double precision, IN "fFalse" double precision) RETURNS double precision AS $$
BEGIN
  IF (b) THEN
    RETURN "fTrue";
  ELSE 
    RETURN "fFalse";
  END IF;
END;
$$ LANGUAGE plpgsql;


CREATE INDEX BAUTEILADR_BESTELLNR_IX ON BAUTEILADR (BESTELLNR);
CREATE INDEX BAUTEILLAGER_SMD_Text_IX ON BAUTEILLAGER (SMD_TEXT);
CREATE INDEX BAUTEILLAGER_LAGERNR_IX ON BAUTEILLAGER (LAGERNR);
CREATE INDEX BAUTEILLAGER_BARCODE_IX ON BAUTEILLAGER (BARCODE);
CREATE INDEX BAUTEILLAGER_BEZ_IX ON BAUTEILLAGER (BEZEICHNUNG);

-- --------------------------------------------------------

--
-- VERSION DATENBANK HINZUFÜGEN
--
DELETE FROM PARAM WHERE PARNR=1;
INSERT INTO PARAM (PARNR, PARNAME, LAND, VALINT, VALFLOAT, VALTEXT) VALUES
(1, 'DB-Version', NULL, NULL, NULL, 'V2.2.13820');

COMMIT;
